==> kpimtextedit_17.12.3.orig.tar.xz: kpimtextedit-17.12.3/src/tableformatdialog.h <==
/*
  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>

  This library is free software; you can redistribute it and/or modify it
  under the terms of the GNU Library General Public License as published by
  the Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This library is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
  License for more details.

  You should have received a copy of the GNU Library General Public License
  along with this library; see the file COPYING.LIB.  If not, write to the
  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  02110-1301, USA.

*/

#ifndef KPIMTEXTEDIT_TABLEFORMATDIALOG_H
#define KPIMTEXTEDIT_TABLEFORMATDIALOG_H

#include "kpimtextedit_export.h"

#include <QDialog>

#include <QTextLength>

namespace KPIMTextEdit {
class KPIMTEXTEDIT_EXPORT TableFormatDialog : public QDialog
{
    Q_OBJECT
public:
    explicit TableFormatDialog(QWidget *parent);
    ~TableFormatDialog();

    int columns() const;
    int rows() const;
    int border() const;

    void setColumns(int);
    void setRows(int);
    void setBorder(int);

    int padding() const;
    void setPadding(int);

    int spacing() const;
    void setSpacing(int);

    void setAlignment(Qt::Alignment alignment);
    Qt::Alignment alignment() const;

    QTextLength::Type typeOfLength() const;
    void setTypeOfLength(QTextLength::Type type);

    int length() const;
    void setLength(int);

    QColor tableBackgroundColor() const;
    void setTableBackgroundColor(const QColor &col);

    bool useBackgroundColor() const;

private:
    class TableFormatDialogPrivate;
    TableFormatDialogPrivate *const d;
};
}
#endif // KPIMTEXTEDIT_TABLEFORMATDIALOG_H

==> kpimtextedit-18.04.3.tar.xz: kpimtextedit-18.04.3/src/tableformatdialog.h <==
/*
  Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>

  This library is free software; you can redistribute it and/or modify it
  under the terms of the GNU Library General Public License as published by
  the Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This library is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
  License for more details.

  You should have received a copy of the GNU Library General Public License
  along with this library; see the file COPYING.LIB.  If not, write to the
  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  02110-1301, USA.

*/

#ifndef KPIMTEXTEDIT_TABLEFORMATDIALOG_H
#define KPIMTEXTEDIT_TABLEFORMATDIALOG_H

#include <QDialog>

#include <QTextLength>

namespace KPIMTextEdit {
class TableFormatDialog : public QDialog
{
    Q_OBJECT
public:
    explicit TableFormatDialog(QWidget *parent);
    ~TableFormatDialog();

    int columns() const;
    int rows() const;
    int border() const;

    void setColumns(int);
    void setRows(int);
    void setBorder(int);

    int padding() const;
    void setPadding(int);

    int spacing() const;
    void setSpacing(int);

    void setAlignment(Qt::Alignment alignment);
    Qt::Alignment alignment() const;

    QTextLength::Type typeOfLength() const;
    void setTypeOfLength(QTextLength::Type type);

    int length() const;
    void setLength(int);

    QColor tableBackgroundColor() const;
    void setTableBackgroundColor(const QColor &col);

    bool useBackgroundColor() const;

private:
    class TableFormatDialogPrivate;
    TableFormatDialogPrivate *const d;
};
}
#endif // KPIMTEXTEDIT_TABLEFORMATDIALOG_H
